@@ -282,15 +282,18 @@ def webbased_entity_check(tar_file, extension):
     
     context, metadata = rocrate.read_metadata(os.path.join(tar_file, "ro-crate-metadata.json"))
     
-    for entity in metadata.values():
-        type = utils.get_norm_value(entity, "@type")[0]
-        id_ = utils.get_norm_value(entity, "@id")[0]
-        
-        ### update result
-        if type == "File" and utils.is_url(id_):
-            urlFile_updRlt(id_, entity, webbased_result, error_message)
-        elif type == "Dataset":
-            dirOnWeb_updRlt(entity, metadata, webbased_result, error_message)
+    hasPart = utils.get_norm_value(metadata["./"], "hasPart") if utils.get_norm_value(metadata["./"], "@type") == ["Dataset"] else []
+    if hasPart != []:
+        for entity in hasPart:
+            try:
+                type = utils.get_norm_value(metadata[entity], "@type")[0]
+                id_ = utils.get_norm_value(metadata[entity], "@id")[0]
+                if type == "File" and utils.is_url(id_):
+                    urlFile_updRlt(id_, metadata[entity], webbased_result, error_message)
+                elif type == "Dataset":
+                    dirOnWeb_updRlt(metadata[entity], metadata, webbased_result, error_message)
+            except KeyError:
+                webbased_result[entity] = [False, error_message["TypeError"].format(entity)]
     
     for values in webbased_result.values():
         if isinstance(values, list):
@@ -298,20 +301,20 @@ def webbased_entity_check(tar_file, extension):
     
     return Result(NAME)
 
-def check_author_type(author, metadata, person_result, error_message):
+def check_author_type(author, metadata, person_result, error_message, warning_message):
     if author != []:
         author = author[0]
         if utils.is_url(author):
-            type = utils.get_norm_value(metadata[author], "@type")
             try:
+                type = utils.get_norm_value(metadata[author], "@type")
                 if type[0] == "Person":
                     person_result[author] = True
                 elif type[0] == "Organization":
                     person_result[author] = warning_message['OrganizationAuthor'].format(author)
                 else:
                     person_result[author] = [False, error_message["TypeError"].format(author)]
-            except IndexError:
-                person_result[author] = [False, error_message["PersonError"].format(author)]
+            except KeyError:
+                person_result[author] = [False, error_message["ReferencingError"].format(author)]
 
 
 def person_entity_check(tar_file, extension):
@@ -323,7 +326,8 @@ def person_entity_check(tar_file, extension):
     NAME = "Person entity check"
     error_message = {
         "PersonError": "Semantic Error: Invalid Person entity {}",
-        "TypeError": "Semantic Error: Invalid @type value of {}"
+        "TypeError": "Semantic Error: Invalid @type value of {}",
+        "ReferencingError": "Semantic Error: Invalid referencing {} NOT Provided. Url Author MUST provide referencing entity."
     }
     warning_message = {
         "OrganizationAuthor" : "WARNING: The Author {} is an Organization"
@@ -334,7 +338,7 @@ def person_entity_check(tar_file, extension):
     context, metadata = rocrate.read_metadata(os.path.join(tar_file, "ro-crate-metadata.json"))
     for entity in metadata.values():
         author = utils.get_norm_value(entity, "author")
-        check_author_type(author, metadata, person_result, error_message)
+        check_author_type(author, metadata, person_result, error_message, warning_message)
     
     for values in person_result.values():
         if isinstance(values, list):
@@ -398,7 +402,7 @@ def publisher_affiliation_correctness(item, entity, metadata, organization_resul
         if utils.get_norm_value(metadata[entity_property], "@type") == ["Organization"]:
             organization_result[utils.get_norm_value(entity, "@id")[0]] = True
         else:
-            organization_result[utils.get_norm_value(entity, "@id")[0]] = [False, error_message["OrganizationError"].format(utils.get_norm_value(metadata[entity_property], "@id"))]
+            organization_result[utils.get_norm_value(entity, "@id")[0]] = [False, error_message["OrganizationError"].format(utils.get_norm_value(metadata[entity_property], "@id")[0])]
         
 def organization_check(tar_file, extension):
     
@@ -419,15 +423,15 @@ def organization_check(tar_file, extension):
     
     context, metadata = rocrate.read_metadata(os.path.join(tar_file, "ro-crate-metadata.json"))
     for entity in metadata.values():
-        type = utils.get_norm_value(entity, "@type")[0]
+        type = utils.get_norm_value(entity, "@type")
         
         ### check the value of publisher for each dataset and scholarly article entity
-        if type =="Dataset" or type == "ScholarlyArticle":
+        if type == ["Dataset"] or type == ["ScholarlyArticle"]:
         	# get_entity("publisher", entity, metadata, organization_result, error_message)
             publisher_affiliation_correctness("publisher", entity, metadata, organization_result, error_message)
             
         ### check the vlaue of affiliation for each file entity
-        elif type == "File":
+        elif type == ["File"]:
         	# get_entity("affiliation", entity, metadata, organization_result, error_message)
             publisher_affiliation_correctness("affiliation", entity, metadata, organization_result, error_message)
     
@@ -457,7 +461,7 @@ def contact_info_check(tar_file, extension):
     
     context, metadata = rocrate.read_metadata(os.path.join(tar_file, "ro-crate-metadata.json"))
     for entity in metadata.values():
-        if utils.get_norm_value(entity, "@type")[0] == "Dataset":
+        if utils.get_norm_value(entity, "@type") == ["Dataset"]:
         	### The flag attributes is to find the additional information which is referencing entity of contactPoint 
         	get_entity("author", entity, metadata, contact_result, error_message, True)
         	get_entity("publisher", entity, metadata, contact_result, error_message, True)
@@ -488,9 +492,9 @@ def citation_check(tar_file, extension):
     
     context, metadata = rocrate.read_metadata(os.path.join(tar_file, "ro-crate-metadata.json"))
     for entity in metadata.values():
-        type = utils.get_norm_value(entity, "@type")[0]
-        if type == "Dataset" or type == "File":
-            get_entity("citation", entity, metadata, citation_result, error_message)
+        type = utils.get_norm_value(entity, "@type")
+        if type == ["Dataset"] or type == ["File"]:
+            get_entity("citation", entity, metadata, citation_result, error_message, urlVal_required = True)
 
     for values in citation_result.values():
         if isinstance(values, list):
@@ -549,15 +553,13 @@ def funder_check(tar_file, extension):
     context, metadata = rocrate.read_metadata(os.path.join(tar_file, "ro-crate-metadata.json"))
     
     for entity in metadata.values():
-        if utils.get_norm_value(entity, "@type")[0] == "Dataset":
-        	get_entity("funder", entity, metadata, funder_result, error_message)
+        if utils.get_norm_value(entity, "@type") == ["Dataset"]:
+        	get_entity("funder", entity, metadata, funder_result, error_message, is_multipleEntity = True)
             # get_funder(depth, entity, metadata, funder_result, error_message)
             
     for values in funder_result.values():
         if isinstance(values, list):
             return Result(NAME, code = -1, message = values[1])
-        if isinstance(values, str):
-        	return Reuslt(NAME, code = 1, message = values)
     
     return Result(NAME)
 
@@ -633,8 +635,9 @@ def places_check(tar_file, extension):
     
     NAME = "Places property check"
     error_message = {
+        "Missingname": "Semantic Error: Invalid Place Entity {}. The Place has geo property SHOULD have a name.",
         "TypeError":"Semantic Error: Invalid Type Value at {}",
-        "ReferencingError": "Semantic Error: Invalid Refernencing or Not Provided"
+        "ReferencingError": "Semantic Error: Invalid Refernencing {} or Not Provided"
     }
     
     geo_result = {}
@@ -645,14 +648,14 @@ def places_check(tar_file, extension):
         entity_type = utils.get_norm_value(entity, "@type")
         if entity_type != []:
 	        if entity_type[0] == "Place":
-	        	get_entity("geo", entity, metadatae, geo_result, error_message)
+	        	get_entity("geo", entity, metadata, geo_result, error_message)
 	        	geoName_required("geo", entity, metadata, geo_result, error_message)
 	        if entity_type[0] == "Dataset" or entity_type == "File":
 	        	geoName_required("contentLocation", entity, metadata, geo_result, error_message)
     
     for values in geo_result.values():
         if isinstance(values, list):
-            return Result(NAME, code = -1, messge = values[1])
+            return Result(NAME, code = -1, message = values[1])
     
     return Result(NAME)
 
@@ -695,31 +698,34 @@ def time_check(tar_file, extension):
     return Result(NAME)
 
 
-def thumbnails_check(tar_file, extension):
+# def thumbnails_check(tar_file, extension):
     
-    """
-    Multiple file in same property(via hasFile) with one of thumbnails. 
-    The thumbnails SHOULD be included in the RO-Crate
-    For more information and exaples, please check:
-    <https://www.researchobject.org/ro-crate/1.1/contextual-entities.html#thumbnails>
-    """
-    
-    NAME = "Thumbnails property check"
-    error_message = {
-        
-    }
-    
-    thumbnails_result = {}
-    
-    context, metadata = rocrate.read_metadata(os.path.join(tar_file, "ro-crate-metadata.json"))
-    for entity in metadata.values():
-        thumbnail = utils.get_norm_value(entity, "thumbnail")
-        hasFile = utils.get_norm_value(entity, "hasFile")
-        if thumbnail != []:
-            if thumbnails[0] in hasFile:
-                thumbnails_result = True
-            else:
-                thumbnails_result = [False, error_message[""]]
+#     """
+#     Multiple file in same property(via hasFile) with one of thumbnails. 
+#     The thumbnails SHOULD be included in the RO-Crate
+#     For more information and exaples, please check:
+#     <https://www.researchobject.org/ro-crate/1.1/contextual-entities.html#thumbnails>
+#     """
+
+#     NAME =  "Thumbnails check"
+#     error_message = {
+#         "ReferencingError": "Semantic Error: Invalid thumbnail {}. The Thumbnail MUST be included in the RO-Crate."
+#     }
+#     thumbnail_result = {}
+
+#     context, metadata = rocrate.read_metadata(os.path.join(tar_file, "ro-crate-metadata.json"))
+
+#     for entity in metadata.values():
+#         thumbnail = utils.get_norm_value(entity, "thumbnail")
+#         hasFile = utils.get_norm_value(entity, "hasFile")
+#         upd_thumbnailRlt(thumbnail, hasFile, thumbnail_result, error_message)
+
+
+#     for values in thumbnail_result.values():
+#         if isinstance(values, list):
+#             return Result(NAME, code = -1, message = values[1])
+
+#     return Result(NAME)
 
 
 def recognisedWkf_upd(extension_set, entity, workflow_result, id_, error_message):
