@@ -39,10 +39,10 @@ def metadata_check(tar_file, extension):
     metadata_file = "ro-crate-metadata.json"
     if extension == "" and os.path.exists(os.path.join(path, metadata_file)):
         return Result(NAME)
-    elif extension == ".zip":
-        zf = zipfile.ZipFile(tar_file, 'r')
-        if metadata_file in zf.namelist():
-            return Result(NAME)
+    # elif extension == ".zip":
+    #     zf = zipfile.ZipFile(tar_file, 'r')
+    #     if metadata_file in zf.namelist():
+    #         return Result(NAME)
     return Result(NAME, code = -1, message = error_message["FileNotFoundError"].format(tar_file))
 
 
@@ -60,14 +60,14 @@ def string_value_check(tar_file, extension):
             except json.JSONDecodeError as e:
                 return Result(NAME, code = -1, message = "Json Syntax Error: %s." %repr(e) + "Validation Aborted.")
 
-    elif extension == ".zip":
-        zf = zipfile.ZipFile(tar_file, 'r')
-        json_string = zf.read(metadata)
-        try:
-            parsed_json = json.loads(json_string)
-            json.dumps(parsed_json, indent = 4, sort_keys = True)
-        except json.JSONDecodeError as e:
-            return Result(NAME, code = -1, message = repr(e))
+    # elif extension == ".zip":
+    #     zf = zipfile.ZipFile(tar_file, 'r')
+    #     json_string = zf.read(metadata)
+    #     try:
+    #         parsed_json = json.loads(json_string)
+    #         json.dumps(parsed_json, indent = 4, sort_keys = True)
+    #     except json.JSONDecodeError as e:
+    #         return Result(NAME, code = -1, message = repr(e))
     
     return Result(NAME)
 
@@ -81,24 +81,22 @@ def check_context(tar_file, extension):
     
     if extension == "":
         with open (os.path.join(tar_file, metadata), 'r') as f:
-            try: 
-                parsed_jsonld = json.load(f)
-            except json.JSONDecodeError as e:
-                return Result(NAME, code = -1, message = repr(e))
+            parsed_jsonld = json.load(f)
+            
         context_data = parsed_jsonld.get("@context")
         if context_data == None:
             return Result(NAME, code = -1, message = error_message["ContextNotFoundError"])
         else:
             return Result(NAME)
 
-    elif extension == ".zip":
-        zf = zipfile.ZipFile(tar_file, 'r')
-        json_string = zf.read(metadata)
-        parsed_jsonld = json.loads(json_string.decode("utf-8"))
-        context_data = parsed_jsonld.get("@context")
+    # elif extension == ".zip":
+    #     zf = zipfile.ZipFile(tar_file, 'r')
+    #     json_string = zf.read(metadata)
+    #     parsed_jsonld = json.loads(json_string.decode("utf-8"))
+    #     context_data = parsed_jsonld.get("@context")
 
-        if context_data == None:
-            return Result(NAME, code = -1, message = error_message["ContextNotFoundError"])
-        else:
-            return Result(NAME)
+    #     if context_data == None:
+    #         return Result(NAME, code = -1, message = error_message["ContextNotFoundError"])
+    #     else:
+    #         return Result(NAME)
 
